========
Overview
========

.. start-badges

.. list-table::
    :stub-columns: 1

    * - docs
      - |docs|
    * - build status
      - |build| |coverage|
    * - package
      - |version| |downloads| |wheel|

.. |docs| image:: https://readthedocs.org/projects/rontgen/badge/?style=flat
    :target: https://readthedocs.org/projects/roentgen/
    :alt: Documentation Status

.. |build| image:: https://travis-ci.org/ehsteve/roentgen.svg?branch=master
    :target: https://travis-ci.org/ehsteve/roentgen
    :alt: Build Status

.. |coverage| image:: https://coveralls.io/repos/github/ehsteve/roentgen/badge.svg?branch=master
    :target: https://coveralls.io/github/ehsteve/roentgen?branch=master
    :alt: Coverage Status

.. |version| image:: https://img.shields.io/pypi/v/roentgen.svg?style=flat
    :alt: PyPI Package latest release
    :target: https://pypi.python.org/pypi/roentgen

.. |downloads| image:: https://img.shields.io/pypi/dm/roentgen.svg?style=flat
    :alt: PyPI Package monthly downloads
    :target: https://pypi.python.org/pypi/roentgen

.. |wheel| image:: https://img.shields.io/pypi/wheel/roentgen.svg?style=flat
    :alt: PyPI Wheel
    :target: https://pypi.python.org/pypi/roentgen

.. end-badges

A Python package for the quantitative analysis of the interaction of energetic x-rays with matter.
This package is named after one of the discoverers of X-rays, Wilhelm Rontgen.

Installation
============

::

    pip install roentgen

Documentation
=============

http://roentgen.readthedocs.io/en/latest/